| ebdt_you | R Documentation |
This function calculate Youden index estimator, their standard error estimated and a confidence interval in a traverse or Cross-sectional study.
ebdt_you(s1, r1, s0, r0, conflev = 0.95, digits = 3, verbose = TRUE)
s1 |
Non-negative numeric. TP - True positive (cases correctly classified as +). |
r1 |
Non-negative numeric. FP - False positives (controls classified as +). |
s0 |
Non-negative numeric. FN - False negatives (cases classified as -). |
r0 |
Non-negative numeric. TN - True negatives (controls classified as -). |
conflev |
Confidence level (0,1). Default 0.95. |
digits |
Integer. Number of decimal places. Default 3. |
verbose |
Logical. If TRUE, it prints the execution time. Default is TRUE. |
Evaluating of Binary Diagnostic Test (EBDT)
This function calculates the Youden Index, standard error & Agresti-Coull CI
- Corrección Haldane–Anscombe *in pairs* if there are zeros: (s1,s0) and/or (r1,r0), +0.5 is added to both cells of the pair. - EE(J) is calculated as: sqrt( Se*(1-Se)/n_cases + Sp*(1-Sp)/n_ctrls ), valid under independence between cases and controls (common in diagnostic studies). - IC is constructed with normal approximation: J ± z * EE(J).
list with: - YoudenIndex: Youden Index estimation J = Se + Sp - 1 - StdError: standard error of J by delta method assuming independence of cases and controls - CI: approximate normal confidence interval for J
Agresti, A., (2002). Categorical Data Analysis. John Wiley and Sons, New York.
Agresti, A., Coull, B.A., (1998). Approximate is better than ‘exact’ for interval estimation of binomial proportions. The American Statistician, 52:119 – 126.
Montero-Alonso, M.Á.(2010). Intervalos de confianza y contrastes de hipótesis para parámetros de tests diagnósticos binarios, http://hdl.handle.net/10481/4879
Pepe, M. S. (2003). The statistical evaluation of medical tests for classification and prediction. Oxford University Press.
Youden, W.J., (1950). Index for rating diagnostic tests. Cancer, 3: 32 – 35.
Zhou, X.-H., Obuchowski, N. A., y McClish, D. K. (2011). Statistical Methods in Diagnostic Medicine (2.ª ed.). John Wiley & Sons.
ebdt_you(40, 5, 10, 45)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.